// This is the JS service to access LG webOS File System
// please go to Gruntfile.js, search "aresPackage" to find more commands relate to how to build the service with the app.
// you need Webos_Signage_SDK installed on your PC.
const Service = require('webos-service');

const service = new Service('com.lg.app.signage.fileIOService');

const NReadline = require('n-readline');

const fs = require('fs');

const ROOT = '/media/internal';

service.register("exists", (message) => {
  const path = ROOT + message.payload.path;

  fs.exists(path, (exists) => {
    if (!exists) {
      message.respond({
        returnValue: false,
        errorCode: 'exists ERROR',
        errorText: 'Not found'
      });
    }
    else {
      message.respond({
        returnValue: true,
        exists: exists
      });
    }
  });
});

// readFile
service.register("readFile", (message) => {
  const path = ROOT + message.payload.path;
  const readLogFromLine = parseInt(message.payload.readLogFromLine, 10) + 1;
  const linesShouldBeRead = parseInt(message.payload.linesShouldBeRead, 10);
  const encoding = message.payload.encoding || 'utf8';
  const linesFromLogFile = [];
  let lineNumberFinal = 0;
  const rl = new NReadline({
    filepath: path,
    encoding: encoding,
    start: readLogFromLine,
    limit: linesShouldBeRead,
    skipEmptyLines: true
  });

  rl.start();
  rl.on('error', (err) => {
    message.respond({
      returnValue: false,
      errorCode: 'readFile ERROR',
      errorText: err.message
    });
  });
  rl.on('line', (line, lineNumber) => {
    const log = line.replace(/\n/, "");
    linesFromLogFile.push(log);
    lineNumberFinal = lineNumber;
  });
  rl.on('end', () => {
    const shouldBeDeleted = linesFromLogFile.length < linesShouldBeRead;
    if (!shouldBeDeleted) {
      message.respond({
        returnValue: true,
        data: JSON.stringify(linesFromLogFile),
        readedLine: lineNumberFinal
      });
    }
    else {
      fs.unlink(path, (err) => {
        if (err) {
          message.respond({
            returnValue: true,
            data: JSON.stringify(linesFromLogFile),
            readedLine: lineNumberFinal
          });
        }
        else {
          message.respond({
            returnValue: true,
            data: JSON.stringify(linesFromLogFile),
            readedLine: -1
          });
        }
      });
    }
  });
});

// writeFile
service.register("writeFile", (message) => {
  const path = ROOT + message.payload.path;
  const data = message.payload.data;
  const encoding = message.payload.encoding || 'utf8';

  fs.appendFile(path, data, encoding, (err) => {
    if (err) {
      message.respond({
        returnValue: false,
        errorCode: 'writeFile ERROR',
        errorText: err
      });
    }
    else {
      message.respond({
        returnValue: true
      });
    }
  });
});

service.register("removeFile", function (message) {
  const path = ROOT + message.payload.path;
  fs.exists(path, (exists) => {
    if (!exists) {
      message.respond({
        returnValue: true
      });
    }
    else {
      fs.unlink(path, function (err) {
        if (err) {
          message.respond({
            returnValue: false,
            errorCode: 'removeFile ERROR',
            errorText: err
          });
        }
        else {
          message.respond({
            returnValue: true
          });
        }
      });
    }
  });
});
